File class

Created by Injoit on 2019-12-27. Copyright © 2019 Quickblox. All rights reserved.

Constructors

File()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getInfo(int id) → Future<QBFile?>
getPrivateURL(String uid) → Future<String?>
getPublicURL(String uid) → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribeUploadProgress(String url, String eventName, dynamic eventMethod, {dynamic onErrorMethod}) → Future<StreamSubscription>
toString() → String
A string representation of this object.
inherited
unsubscribeUploadProgress(String url, String eventName) → Future<void>
upload(String url, {bool public = false}) → Future<QBFile?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CHANNEL_NAME → const String
//////////////////////////////////////////////////////////////////////// ////////////////////////////////////////////////////////////////////////
GET_INFO_METHOD → const String
GET_PRIVATE_URL_METHOD → const String
GET_PUBLIC_URL_METHOD → const String
SUBSCRIBE_UPLOAD_PROGRESS_METHOD → const String
UNSUBSCRIBE_UPLOAD_PROGRESS_METHOD → const String
UPLOAD_METHOD → const String