QBEvent class

Created by Injoit on 2019-12-27. Copyright © 2019 Quickblox. All rights reserved.

Constructors

QBEvent()

Properties

active ↔ bool?
getter/setter pair
date ↔ double?
getter/setter pair
endDate ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
notificationType ↔ String?
getter/setter pair
occuredCount ↔ int?
getter/setter pair
payload ↔ String?
getter/setter pair
period ↔ String?
getter/setter pair
pushType ↔ int?
getter/setter pair
recipientsIds ↔ List<String>?
getter/setter pair
recipientsTagsAll ↔ List<String>?
getter/setter pair
recipientsTagsAny ↔ List<String>?
getter/setter pair
recipientsTagsExclude ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited