QBFile class

Created by Injoit on 2019-12-27. Copyright © 2019 Quickblox. All rights reserved.

Constructors

QBFile()

Properties

completedAt ↔ String?
getter/setter pair
contentType ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
isPublic ↔ bool?
getter/setter pair
lastReadAccessTime ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
getter/setter pair
tags ↔ String?
getter/setter pair
uid ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited